@@ -24,6 +24,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
              filepath_timestamps_ball: Optional[str] = None,
              filepath_daq: Optional[str] = None,
              filepath_annotations: Optional[str] = None,
+             filepath_definitions: Optional[str] = None,
              target_sampling_rate: float = 1_000, audio_sampling_rate: Optional[float] = None,
              audio_channels: Optional[List[int]] = None, audio_dataset: str = None,
              event_names: Optional[List[str]] = None, event_categories: Optional[List[str]] = None,
@@ -46,6 +47,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
         filepath_video (str, optional): Path to the video file. Defaults to None (infer path from `datename` and `dat_path`).
         filepath_daq (str, optional): Path to the daq file. Defaults to None (infer path from `datename` and `dat_path`).
         filepath_annotations (str, optional): Path to annotations file. Defaults to None (infer path from `datename` and `res_path`).
+        filepath_definitions (str, optional): Path to song definitions file. Defaults to None (infer path from `datename` and `res_path`).
         target_sampling_rate (int, optional): Sampling rate in Hz for pose and annotation data. Defaults to 1000.
         audio_sampling_rate (int, optional): Audio sampling rate in Hz.
                                              Used to override sampling rate inferred from file or to provide sampling rate if missing from file.
@@ -111,6 +113,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
                                      basename_is_full_name=filepath_daq_is_custom)
         if audio_loader is None and filepath_daq_is_custom:
             audio_loader = io.audio.AudioFile(basename)
+
         try:
             song_raw, non_song_raw, sampling_rate = audio_loader.load(audio_loader.path, song_channels=audio_channels,
                                                                       return_nonsong_channels=True, lazy=lazy_load_song,
@@ -283,6 +286,28 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
             logging.info('   Found no manual automatic annotations.')
         logging.info('Done.')
 
+        # load SONG DEFINITIONS
+        logging.info('Loading song definitions:')
+        custom_filepath_definitions = filepath_definitions is not None
+        if not custom_filepath_definitions:
+            filepath_definitions = os.path.join(root, res_path, datename, datename)  # or construct form audio file name - .ext + _definitions.csv
+
+        definitions_loader = io.get_loader(kind='definitions_manual', basename=filepath_definitions, basename_is_full_name=custom_filepath_definitions)
+        if definitions_loader:
+            try:
+                manual_event_seconds_loaded, manual_event_categories_loaded = definitions_loader.load(definitions_loader.path)
+                manual_event_seconds.update(manual_event_seconds_loaded)
+                manual_event_categories.update(manual_event_categories_loaded)
+                logging.info(f'   {definitions_loader.path} loaded.')
+            except Exception as e:
+                logging.info(f'   Loading {definitions_loader.path} failed.')
+                logging.exception(e)
+
+        else:
+            logging.info('   Found no song definitions.')
+        logging.info('Done.')
+
+
         # load RAW song traces
         logging.info('Loading audio data:')
         if not filepath_daq_is_custom:
@@ -365,7 +390,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
                                             'amplitude_units': 'volts'})
             dataset_data['non_song_raw'] = non_song_raw
 
-    logging.info('   segmentations')
+    logging.info('   Segmentations')
     song_events = np.zeros((len(time), len(event_seconds)), dtype=np.int16)
     song_events = xr.DataArray(data=song_events,  # start with empty song_events matrix
                                 dims=['time', 'event_types'],
@@ -386,7 +411,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
         dataset_data['event_names'] = ds_eventtimes.event_names
         dataset_data['event_names'].attrs['possible_event_names'] = ds_eventtimes.attrs['possible_event_names']
     except Exception as e:
-        logging.error('Failed to generate event_times data arrays:')
+        logging.error('      Failed to generate event_times data arrays:')
         logging.exception(e)
 
     # BODY POSITION
@@ -394,7 +419,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
         pixel_size_mm = np.nan
 
     if with_tracks:
-        logging.info('   tracking')
+        logging.info('   Tracking')
         xr_tracks = align_time(xr_tracks, ss, target_samples, ref_time=ref_time, target_time=time, extrapolate=True)
         xr_tracks.attrs.update({'description': 'coords are "allocentric" - rel. to the full frame',
                                         'sampling_rate_Hz': sampling_rate / step,
@@ -407,7 +432,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
 
     # POSES
     if with_poses:
-        logging.info('   poses')
+        logging.info('   Poses')
         xr_poses = align_time(xr_poses, ss, target_samples, ref_time=ref_time, target_time=time)
         xr_poses.attrs.update({'description': 'coords are "egocentric" - rel. to box',
                                     'sampling_rate_Hz': sampling_rate / step,
@@ -432,7 +457,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
 
     # BALLTRACKS
     if with_balltracker:
-        logging.info('   balltracker')
+        logging.info('   Balltracker')
         xr_balltracks = align_time(xr_balltracks, ss_ball, target_samples, target_time=time,
                                    dim='frame_number_ball', suffix='_ball', ref_time=ref_time)
         xr_balltracks.attrs.update({'description': '',
@@ -443,7 +468,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
 
     # MOVIEPARAMS
     if with_movieparams:
-        logging.info('   movieparams')
+        logging.info('   Movieparams')
         xr_movieparams = align_time(xr_movieparams, ss_movie, target_samples, dim='frame_number_movie', suffix='_movie',
                                     ref_time=ref_time, target_time=time, extrapolate=True)
         xr_movieparams.attrs.update({'description': '',
@@ -453,7 +478,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
         dataset_data['movieparams'] = xr_movieparams
 
     # MAKE THE DATASET
-    logging.info('   assembling')
+    logging.info('   Assembling')
 
     dataset = xr.Dataset(dataset_data, attrs={})
     if 'time' not in dataset:
@@ -481,7 +506,7 @@ def assemble(datename: Optional[str] = '', root: str = '', dat_path: str = 'dat'
             dataset.attrs['swap_events'] = [[ii, f1, f2] for ii, f1, f2 in zip(indices, flies1, flies2)]
             logging.info(f'  Fixed fly identities using info from {filepath_swap}.')
         except (FileNotFoundError, OSError) as e:
-            logging.debug(f'  Could not load fly identities using info from {filepath_swap}.')
+            logging.debug(f'      Could not load fly identities using info from {filepath_swap}.')
             logging.debug(e)
     logging.info('Done.')
     return dataset
@@ -495,7 +520,6 @@ def add_time(ds, ss, dim: str = 'frame_number', suffix: str = ''):
 
 def align_time(ds, ss, target_samples, target_time, ref_time, dim: str = 'frame_number',
                suffix: str = '', time=None, extrapolate: bool = False):
-
     target_frames_float = ss.times2frames(ss.sample_time(target_samples))
     interp_kwargs = {}
     if extrapolate:
@@ -517,7 +541,7 @@ def align_time(ds, ss, target_samples, target_time, ref_time, dim: str = 'frame_
     return ds
 
 
-def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smooth_positions: bool = True):
+def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smooth_positions: bool = True, infer_timestep_from_ds: bool = False):
     """[summary]
 
     Args:
@@ -525,6 +549,7 @@ def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smoo
         make_abs (bool, optional): [description]. Defaults to True.
         make_rel (bool, optional): [description]. Defaults to True.
         smooth_positions (bool, optional): [description]. Defaults to True.
+        infer_timestep_from_ds (bool, optional): Defaults to False.
 
     Returns:
         [type]: [description]
@@ -550,6 +575,14 @@ def assemble_metrics(dataset, make_abs: bool = True, make_rel: bool = True, smoo
     sampling_rate = dataset.pose_positions.attrs['sampling_rate_Hz']
     frame_rate = dataset.pose_positions.attrs['video_fps']
 
+    # TODO:
+    # - all calls get timestep arg
+    # - update spatial and time units in attrs
+    if infer_timestep_from_ds:
+        timestep = 1  # do sth here with the sampling_rate of the poses? or compute mean sample interval in case data are unevenly sampled?
+    else:
+        timestep = 1
+
     thoraces = dataset.pose_positions_allo.loc[:, :, 'thorax', :].values.astype(np.float32)
     heads = dataset.pose_positions_allo.loc[:, :, 'head', :].values.astype(np.float32)
     wing_left = dataset.pose_positions_allo.loc[:, :, 'left_wing', :].values.astype(np.float32)
